from nodeconductor.core import NodeConductorExtension


class ZabbixExtension(NodeConductorExtension):

    class Settings:
        NODECONDUCTOR_ZABBIX = {
            'SMS_SETTINGS': {
                # configurations for default SMS notifications.
                'SMS_EMAIL_FROM': None,
                'SMS_EMAIL_RCPT': None,
            },
        }

    @staticmethod
    def django_app():
        return 'nodeconductor_zabbix'

    @staticmethod
    def rest_urls():
        from .urls import register_in
        return register_in

    @staticmethod
    def celery_tasks():
        from datetime import timedelta
        return {
            'update-monthly-slas': {
                'task': 'nodeconductor.zabbix.update_sla',
                'schedule': timedelta(minutes=5),
                'args': ('monthly',),
            },
            'update-yearly-slas': {
                'task': 'nodeconductor.zabbix.update_sla',
                'schedule': timedelta(minutes=10),
                'args': ('yearly',),
            },
            'update-monitoring-items': {
                'task': 'nodeconductor.zabbix.update_monitoring_items',
                'schedule': timedelta(minutes=10),
            },
            'pull-zabbix-hosts': {
                'task': 'nodeconductor.zabbix.pull_hosts',
                'schedule': timedelta(minutes=30),
            },
        }



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nodeconductor_zabbix', '0012_users_and_groups'),
    ]

    operations = [
        migrations.AddField(
            model_name='host',
            name='error',
            field=models.CharField(help_text='Error text if Zabbix agent is unavailable.', max_length=500, blank=True),
        ),
        migrations.AddField(
            model_name='host',
            name='status',
            field=models.CharField(default='0', max_length=30, choices=[('0', 'monitored'), ('1', 'unmonitored')]),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nodeconductor_zabbix', '0013_host_status_and_error'),
    ]

    operations = [
        migrations.RenameField(
            model_name='item',
            old_name='name',
            new_name='key',
        ),
        migrations.AddField(
            model_name='item',
            name='name',
            field=models.CharField(default='item', max_length=255),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nodeconductor_zabbix', '0009_itservices_as_resource'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='zabbixserviceprojectlink',
            name='error_message',
        ),
        migrations.RemoveField(
            model_name='zabbixserviceprojectlink',
            name='state',
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import uuidfield.fields
import django_fsm
import nodeconductor.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('structure', '0034_change_service_settings_state_field'),
        ('nodeconductor_zabbix', '0011_migrate_state_field'),
    ]

    operations = [
        migrations.CreateModel(
            name='User',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=150, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('error_message', models.TextField(blank=True)),
                ('state', django_fsm.FSMIntegerField(default=5, choices=[(5, 'Creation Scheduled'), (6, 'Creating'), (1, 'Update Scheduled'), (2, 'Updating'), (7, 'Deletion Scheduled'), (8, 'Deleting'), (3, 'OK'), (4, 'Erred')])),
                ('backend_id', models.CharField(max_length=255, db_index=True)),
                ('alias', models.CharField(max_length=150)),
                ('surname', models.CharField(max_length=150)),
                ('type', models.CharField(default='1', max_length=30, choices=[('1', 'default'), ('2', 'admin'), ('3', 'superadmin')])),
                ('password', models.CharField(max_length=150, blank=True)),
                ('phone', models.CharField(max_length=30, blank=True)),
            ],
        ),
        migrations.CreateModel(
            name='UserGroup',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=150, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('backend_id', models.CharField(max_length=255, db_index=True)),
                ('settings', models.ForeignKey(related_name='+', to='structure.ServiceSettings')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AddField(
            model_name='user',
            name='groups',
            field=models.ManyToManyField(related_name='users', to='nodeconductor_zabbix.UserGroup'),
        ),
        migrations.AddField(
            model_name='user',
            name='settings',
            field=models.ForeignKey(related_name='+', to='structure.ServiceSettings'),
        ),
        migrations.AlterUniqueTogether(
            name='usergroup',
            unique_together=set([('settings', 'backend_id')]),
        ),
        migrations.AlterUniqueTogether(
            name='user',
            unique_together=set([('alias', 'settings')]),
        ),
    ]



from nodeconductor.core.permissions import StaffPermissionLogic
from nodeconductor.structure import perms as structure_perms


PERMISSION_LOGICS = (
    ('nodeconductor_zabbix.ZabbixService', structure_perms.service_permission_logic),
    ('nodeconductor_zabbix.ZabbixServiceProjectLink', structure_perms.service_project_link_permission_logic),
    ('nodeconductor_zabbix.Host', structure_perms.resource_permission_logic),
    ('nodeconductor_zabbix.ITService', structure_perms.resource_permission_logic),
    ('nodeconductor_zabbix.Template', StaffPermissionLogic(any_permission=True)),
    ('nodeconductor_zabbix.Trigger', StaffPermissionLogic(any_permission=True)),
    ('nodeconductor_zabbix.SlaHistory', StaffPermissionLogic(any_permission=True)),
    ('nodeconductor_zabbix.SlaHistoryEvent', StaffPermissionLogic(any_permission=True)),
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import uuidfield.fields

import nodeconductor.core.models
import nodeconductor.core.validators
import nodeconductor.logging.loggers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('structure', '0032_make_options_optional'),
        ('nodeconductor_zabbix', '0007_add_sla'),
    ]

    operations = [
        migrations.CreateModel(
            name='ITService',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=150, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('backend_id', models.CharField(max_length=255, db_index=True)),
                ('settings', models.ForeignKey(related_name='+', to='structure.ServiceSettings')),
                ('agreed_sla', models.DecimalField(null=True, max_digits=6, decimal_places=4, blank=True)),
                ('algorithm', models.PositiveSmallIntegerField(default=0, choices=[(0, b'do not calculate'), (1, b'problem, if at least one child has a problem'), (2, b'problem, if all children have problems')])),
                ('sort_order', models.PositiveSmallIntegerField(default=1)),
                ('host', models.ForeignKey(on_delete=models.deletion.PROTECT, blank=True, to='nodeconductor_zabbix.Host', null=True)),
                ('backend_trigger_id', models.CharField(max_length=64, null=True, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='itservice',
            unique_together=set([('settings', 'backend_id')]),
        ),
        migrations.CreateModel(
            name='Trigger',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=255, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('backend_id', models.CharField(max_length=255, db_index=True)),
                ('settings', models.ForeignKey(related_name='+', to='structure.ServiceSettings')),
                ('template', models.ForeignKey(related_name='triggers', to='nodeconductor_zabbix.Template')),
            ],
            options={
                'abstract': False,
            },
            bases=(models.Model,),
        ),
        migrations.AlterUniqueTogether(
            name='trigger',
            unique_together=set([('settings', 'backend_id')]),
        ),
        migrations.AddField(
            model_name='itservice',
            name='trigger',
            field=models.ForeignKey(blank=True, to='nodeconductor_zabbix.Trigger', null=True),
            preserve_default=False,
        ),
        migrations.RemoveField(
            model_name='host',
            name='agreed_sla',
        ),
        migrations.RemoveField(
            model_name='host',
            name='service_id',
        ),
        migrations.RemoveField(
            model_name='host',
            name='trigger_id',
        ),
        migrations.AlterField(
            model_name='item',
            name='name',
            field=models.CharField(max_length=255),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='slahistory',
            name='itservice',
            field=models.ForeignKey(to='nodeconductor_zabbix.ITService'),
            preserve_default=False,
        ),
        migrations.AlterUniqueTogether(
            name='slahistory',
            unique_together=set([('itservice', 'period')]),
        ),
        migrations.RemoveField(
            model_name='slahistory',
            name='host',
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import django_fsm


def migrate_state_field(apps, schema_editor):
    Host = apps.get_model('nodeconductor_zabbix', 'Host')
    ITService = apps.get_model('nodeconductor_zabbix', 'ITService')

    migrate_state(Host)
    migrate_state(ITService)


def migrate_state(model):
    from nodeconductor.structure.models import OldStateResourceMixin
    from nodeconductor.core.models import StateMixin

    states_map = {
        OldStateResourceMixin.States.PROVISIONING_SCHEDULED: StateMixin.States.CREATION_SCHEDULED,
        OldStateResourceMixin.States.PROVISIONING: StateMixin.States.CREATING,

        OldStateResourceMixin.States.ONLINE: StateMixin.States.OK,
        OldStateResourceMixin.States.OFFLINE: StateMixin.States.OK,

        OldStateResourceMixin.States.STARTING_SCHEDULED: StateMixin.States.UPDATE_SCHEDULED,
        OldStateResourceMixin.States.STARTING: StateMixin.States.UPDATING,

        OldStateResourceMixin.States.STOPPING_SCHEDULED: StateMixin.States.UPDATE_SCHEDULED,
        OldStateResourceMixin.States.STOPPING: StateMixin.States.UPDATING,

        OldStateResourceMixin.States.ERRED: StateMixin.States.ERRED,

        OldStateResourceMixin.States.DELETION_SCHEDULED: StateMixin.States.DELETION_SCHEDULED,
        OldStateResourceMixin.States.DELETING: StateMixin.States.DELETING,

        OldStateResourceMixin.States.RESIZING_SCHEDULED: StateMixin.States.UPDATE_SCHEDULED,
        OldStateResourceMixin.States.RESIZING: StateMixin.States.UPDATING,

        OldStateResourceMixin.States.RESTARTING_SCHEDULED: StateMixin.States.UPDATE_SCHEDULED,
        OldStateResourceMixin.States.RESTARTING: StateMixin.States.UPDATING,
    }

    for instance in model.objects.all():
        instance.state = states_map[instance.state]
        instance.save()


class Migration(migrations.Migration):

    dependencies = [
        ('nodeconductor_zabbix', '0010_remove_spl_state'),
    ]

    operations = [
        migrations.AlterField(
            model_name='host',
            name='state',
            field=django_fsm.FSMIntegerField(default=5, choices=[(5, 'Creation Scheduled'), (6, 'Creating'), (1, 'Update Scheduled'), (2, 'Updating'), (7, 'Deletion Scheduled'), (8, 'Deleting'), (3, 'OK'), (4, 'Erred')]),
        ),
        migrations.AlterField(
            model_name='itservice',
            name='state',
            field=django_fsm.FSMIntegerField(default=5, choices=[(5, 'Creation Scheduled'), (6, 'Creating'), (1, 'Update Scheduled'), (2, 'Updating'), (7, 'Deletion Scheduled'), (8, 'Deleting'), (3, 'OK'), (4, 'Erred')]),
        ),

        migrations.RunPython(migrate_state_field),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.db.models.deletion
import django.utils.timezone
import model_utils.fields
import taggit.managers
import django_fsm


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('nodeconductor_zabbix', '0008_add_itservice_trigger'),
    ]

    operations = [
        migrations.AddField(
            model_name='itservice',
            name='created',
            field=model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='description',
            field=models.CharField(max_length=500, verbose_name='description', blank=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='error_message',
            field=models.TextField(blank=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='is_main',
            field=models.BooleanField(default=True, help_text='Main IT service SLA will be added to hosts resource as monitoring item.'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='modified',
            field=model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='service_project_link',
            field=models.ForeignKey(related_name='itservices', on_delete=django.db.models.deletion.PROTECT, default=1, to='nodeconductor_zabbix.ZabbixServiceProjectLink'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='itservice',
            name='start_time',
            field=models.DateTimeField(null=True, blank=True),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='state',
            field=django_fsm.FSMIntegerField(default=1, help_text='WARNING! Should not be changed manually unless you really know what you are doing.', choices=[(1, 'Provisioning Scheduled'), (2, 'Provisioning'), (3, 'Online'), (4, 'Offline'), (5, 'Starting Scheduled'), (6, 'Starting'), (7, 'Stopping Scheduled'), (8, 'Stopping'), (9, 'Erred'), (10, 'Deletion Scheduled'), (11, 'Deleting'), (13, 'Resizing Scheduled'), (14, 'Resizing'), (15, 'Restarting Scheduled'), (16, 'Restarting')]),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='itservice',
            name='tags',
            field=taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text='A comma-separated list of tags.', verbose_name='Tags'),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='itservice',
            name='backend_id',
            field=models.CharField(max_length=255, blank=True),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='itservice',
            name='host',
            field=models.ForeignKey(related_name='itservices', blank=True, to='nodeconductor_zabbix.Host', null=True),
            preserve_default=True,
        ),
        migrations.AlterUniqueTogether(
            name='itservice',
            unique_together=set([('host', 'is_main')]),
        ),
        migrations.RemoveField(
            model_name='itservice',
            name='settings',
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import nodeconductor.core.models
import django_fsm
import jsonfield.fields
import django.db.models.deletion
import django.utils.timezone
import nodeconductor.logging.loggers
import uuidfield.fields
import taggit.managers
import model_utils.fields
import nodeconductor.core.validators


class Migration(migrations.Migration):

    replaces = [('nodeconductor_zabbix', '0001_initial'), ('nodeconductor_zabbix', '0002_add_error_message'), ('nodeconductor_zabbix', '0003_resource_error_message'), ('nodeconductor_zabbix', '0004_host_tags'), ('nodeconductor_zabbix', '0005_templates_and_items'), ('nodeconductor_zabbix', '0006_extend_items'), ('nodeconductor_zabbix', '0007_add_sla')]

    dependencies = [
        ('taggit', '0002_auto_20150616_2121'),
        ('contenttypes', '0001_initial'),
        ('structure', '0025_add_zabbix_to_settings'),
    ]

    operations = [
        migrations.CreateModel(
            name='ZabbixService',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=150, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('settings', models.ForeignKey(to='structure.ServiceSettings')),
                ('customer', models.ForeignKey(to='structure.Customer')),
                ('available_for_all', models.BooleanField(default=False, help_text='Service will be automatically added to all customers projects if it is available for all')),
            ],
            options={
                'abstract': False,
            },
            bases=(nodeconductor.core.models.SerializableAbstractMixin, nodeconductor.logging.loggers.LoggableMixin, models.Model),
        ),
        migrations.CreateModel(
            name='ZabbixServiceProjectLink',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('state', django_fsm.FSMIntegerField(default=5, choices=[(0, 'New'), (5, 'Creation Scheduled'), (6, 'Creating'), (1, 'Sync Scheduled'), (2, 'Syncing'), (3, 'In Sync'), (4, 'Erred')])),
                ('project', models.ForeignKey(to='structure.Project')),
                ('service', models.ForeignKey(to='nodeconductor_zabbix.ZabbixService')),
                ('error_message', models.TextField(blank=True)),
            ],
            bases=(nodeconductor.core.models.SerializableAbstractMixin, nodeconductor.core.models.DescendantMixin, nodeconductor.logging.loggers.LoggableMixin, models.Model),
        ),
        migrations.AlterUniqueTogether(
            name='zabbixservice',
            unique_together=set([('customer', 'settings')]),
        ),
        migrations.AlterUniqueTogether(
            name='zabbixserviceprojectlink',
            unique_together=set([('service', 'project')]),
        ),
        migrations.AddField(
            model_name='zabbixservice',
            name='projects',
            field=models.ManyToManyField(related_name='zabbix_services', through='nodeconductor_zabbix.ZabbixServiceProjectLink', to=b'structure.Project'),
        ),
        migrations.CreateModel(
            name='Template',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=150, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('backend_id', models.CharField(max_length=255, db_index=True)),
                ('settings', models.ForeignKey(related_name='+', to='structure.ServiceSettings')),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.AlterUniqueTogether(
            name='template',
            unique_together=set([('settings', 'backend_id')]),
        ),
        migrations.CreateModel(
            name='Host',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', model_utils.fields.AutoCreatedField(default=django.utils.timezone.now, verbose_name='created', editable=False)),
                ('modified', model_utils.fields.AutoLastModifiedField(default=django.utils.timezone.now, verbose_name='modified', editable=False)),
                ('description', models.CharField(max_length=500, verbose_name='description', blank=True)),
                ('name', models.CharField(max_length=64, verbose_name='name', validators=[nodeconductor.core.validators.validate_name])),
                ('uuid', uuidfield.fields.UUIDField(unique=True, max_length=32, editable=False, blank=True)),
                ('backend_id', models.CharField(max_length=255, blank=True)),
                ('start_time', models.DateTimeField(null=True, blank=True)),
                ('state', django_fsm.FSMIntegerField(default=1, help_text='WARNING! Should not be changed manually unless you really know what you are doing.', choices=[(1, 'Provisioning Scheduled'), (2, 'Provisioning'), (3, 'Online'), (4, 'Offline'), (5, 'Starting Scheduled'), (6, 'Starting'), (7, 'Stopping Scheduled'), (8, 'Stopping'), (9, 'Erred'), (10, 'Deletion Scheduled'), (11, 'Deleting'), (13, 'Resizing Scheduled'), (14, 'Resizing'), (15, 'Restarting Scheduled'), (16, 'Restarting')])),
                ('visible_name', models.CharField(max_length=64, verbose_name='visible name')),
                ('interface_parameters', jsonfield.fields.JSONField(blank=True)),
                ('host_group_name', models.CharField(max_length=64, verbose_name='host group name', blank=True)),
                ('object_id', models.PositiveIntegerField(null=True)),
                ('content_type', models.ForeignKey(to='contenttypes.ContentType', null=True)),
                ('service_project_link', models.ForeignKey(related_name='hosts', on_delete=django.db.models.deletion.PROTECT, to='nodeconductor_zabbix.ZabbixServiceProjectLink')),
                ('error_message', models.TextField(blank=True)),
                ('tags', taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text='A comma-separated list of tags.', verbose_name='Tags')),
                ('templates', models.ManyToManyField(related_name='hosts', to=b'nodeconductor_zabbix.Template')),
                ('agreed_sla', models.DecimalField(null=True, max_digits=6, decimal_places=4, blank=True)),
                ('service_id', models.CharField(max_length=255, blank=True)),
                ('trigger_id', models.CharField(max_length=255, blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=(nodeconductor.core.models.SerializableAbstractMixin, nodeconductor.core.models.DescendantMixin, nodeconductor.logging.loggers.LoggableMixin, models.Model),
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('name', models.CharField(max_length=64)),
                ('template', models.ForeignKey(related_name='items', to='nodeconductor_zabbix.Template')),
                ('backend_id', models.CharField(max_length=64)),
                ('delay', models.IntegerField()),
                ('history', models.IntegerField()),
                ('units', models.CharField(max_length=255)),
                ('value_type', models.IntegerField(choices=[(0, b'Numeric (float)'), (1, b'Character'), (2, b'Log'), (3, b'Numeric (unsigned)'), (4, b'Text')])),
            ],
        ),
        migrations.CreateModel(
            name='SlaHistory',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('period', models.CharField(max_length=10)),
                ('value', models.DecimalField(null=True, max_digits=11, decimal_places=4, blank=True)),
                ('host', models.ForeignKey(to='nodeconductor_zabbix.Host')),
            ],
            options={
                'verbose_name': 'SLA history',
                'verbose_name_plural': 'SLA histories',
            },
        ),
        migrations.CreateModel(
            name='SlaHistoryEvent',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('timestamp', models.IntegerField()),
                ('state', models.CharField(max_length=1, choices=[(b'U', b'DOWN'), (b'D', b'UP')])),
                ('history', models.ForeignKey(related_name='events', to='nodeconductor_zabbix.SlaHistory')),
            ],
        ),
        migrations.AlterUniqueTogether(
            name='slahistory',
            unique_together=set([('host', 'period')]),
        ),
    ]
